embassy-stm32

Crates

git

Versions

stm32l071rb

Flavors

TIM21

Struct TIM21 

pub struct TIM21 { /* private fields */ }
TIM21 peripheral

Implementations

Source

impl TIM21

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.